@@ -133,9 +133,9 @@ class CooccurrenceExternalManager():
         if platform.system() == 'Windows':
             executable = 'ccount.exe '
         elif platform.system() == 'Darwin':
-            executable = 'ccount_mac '
+            executable = './ccount_mac '
         elif platform.system() == 'Linux':
-            executable = 'ccount '
+            executable = './ccount '
 
         program = ' -i ' + self.input_file + ' -o ' + self.output_file + ' -w ' + str(self.num_workers) + ' --threshold ' + str(self.threshold)
 
